PALM-meteo: palmmeteo/utils.py File Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Namespaces | Functions | Variables
utils.py File Reference

## Classes
class | palmmeteo.utils.NotWholeTimestep
class | palmmeteo.utils.DTIndexer
class | palmmeteo.utils.SliceExtender
class | palmmeteo.utils.SliceBoolExtender
class | palmmeteo.utils.Workflow

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.utils

## Functions
| palmmeteo.utils.parse_pos (pos, ngrid, resol)
| palmmeteo.utils.distribute (what, into, reverse=False)
| palmmeteo.utils.distribute_chunks (sizes, nthreads, prefix=(), reverse=False)
| palmmeteo.utils.find_free_fname (fpath, overwrite=False)
| palmmeteo.utils.tstep (td, step)
| palmmeteo.utils.ensure_dimension (f, dimname, dimsize)
| palmmeteo.utils.getvar (f, varname, *args, **kwargs)
| palmmeteo.utils.assert_dir (filepath)

## Variables
| palmmeteo.utils.ax_ = np.newaxis
int | palmmeteo.utils.rad = np.pi / 180.
| palmmeteo.utils.td0 = datetime.timedelta(0)
| palmmeteo.utils.utc = datetime.timezone.utc
| palmmeteo.utils.midnight = datetime.time(0)
dt | palmmeteo.utils.utcdefault = lambda dt.replace(tzinfo=utc) if dt.tzinfo is None else dt
datetime | palmmeteo.utils.midnight_of = lambda dt.datetime.combine(dt.date(), midnight, dt.tzinfo)
int | palmmeteo.utils.eps_grid = 1e-3
| palmmeteo.utils.fext_re = re.compile(r'\.(\d{3})$')
| palmmeteo.utils.pos_re = re.compile(, re.X)
| palmmeteo.utils.where_range = lambda mask: (np.argmax(mask), len(mask)-np.argmax(mask[::-1]))
min | palmmeteo.utils.nearest_gridpt = lambda v, ngrid(ngrid-1, max(0, round(v)))